<div class="d-flex align-items-end mb-3">
    <b class="large">Measurements in {{friendly_month(date('Y-m-d'))}}</b>
</div>
<table class="table table-striped table-sm table-bordered mb-0">
    <thead>
        <tr>
            <th class="border-0 px-2 text-secondary">Patient</th>
            <th class="border-0 px-2 text-secondary">Category</th>
            <th class="border-0 px-2 text-secondary">Value</th>
            <th class="border-0 px-2 text-secondary">Timestamp</th>
            <th class="border-0 px-2 text-secondary">Mins this month</th>
            <th class="border-0 px-2 text-secondary">Stamp</th>
            <th class="border-0 px-2 text-secondary text-center">Entry</th>
        </tr>
    </thead>
    <tbody>
        @if(count($measurements))
            <?php foreach($measurements as $measurement): ?>
                <tr>
                    <td class="px-2">
                        <a href="/patients/view/{{$measurement->client_uid}}" class="font-weight-bold">
                            {{ $measurement->name_first }} {{ $measurement->name_last }}
                        </a>
                    </td>
                    <td class="px-2">{{ $measurement->label }}</td>
                    <td class="px-2">
                        @if($measurement->label === 'BP')
                            {{ $measurement->sbp_mm_hg }}/{{ $measurement->dbp_mm_hg }} mmHg
                        @elseif($measurement->label === 'Wt. (lbs.)')
                            {{ round(floatval($measurement->numeric_value), 2) }} lbs
                        @else
                            {{ $measurement->value }}
                        @endif
                    </td>
                    <td>
                        {{ friendly_date_time_short_with_tz_from_timestamp_divide1000($measurement->ts, 'EASTERN') }}
                        EST
                    </td>
                    <td class="px-2">
                        @if($measurement->rm_total_time_in_seconds)
                            {{ floor($measurement->rm_total_time_in_seconds/60) }}
                        @else
                            0
                        @endif
                    </td>
                    <td colspan="px-2">
                        <span moe large relative>
                            <a start show class="py-0 mb-3 font-weight-bold">Update status</a>
                            <form url="/api/measurement/updateStatus" right>
                                <input type="hidden" name="uid" value="{{$measurement->uid}}">
                                <select name="status" id="" class="form-control input-sm">
                                    <option value="">--select--</option>
                                    <option value="ACK">Ok</option>
                                    <option value="INVALID_ACK">Invalid</option>
                                </select>
                                <div class="d-flex align-items-center mt-2">
                                    <button class="btn btn-sm btn-success mr-2" submit>Submit</button>
                                    <button class="btn btn-sm btn-default mr-2 border" cancel>Cancel</button>
                                </div>
                            </form>
                        </span>
                    </td>
                    <td colspan="px-2">
                        <div class="text-center">
                            <span moe large relative>
                                <a start show class="py-0 mb-3 font-weight-bold">Add</a>
                                <form url="/api/careMonthEntry/createForRm" right>
                                    <p class="mb-2 d-block text-left"><b>Add RM Entry</b></p>
                                    <input type="hidden" name="careMonthUid" value="{{$measurement->care_month_uid}}">
                                    <input type="hidden" name="proUid" value="{{$pro->uid}}">
                                    <input type="hidden" name="effectiveDate" value="{{date('Y-m-d')}}">
                                    <div class="bg-light border rounded p-2 mb-2">
                                        <div class="mb-1 d-flex align-items-center">
                                            <span class="width-50px text-left text-secondary">Type</span>
                                            <div><b>{{ $measurement->label }} </b></div>
                                        </div>
                                        <div class="d-flex align-items-center">
                                            <span class="width-50px text-left text-secondary">Value</span>
                                            <div>
                                                @if($measurement->label == 'BP')
                                                <div>
                                                    <b>{{ $measurement->sbp_mm_hg }}/{{ $measurement->dbp_mm_hg }} mmHg</b>
                                                </div>
                                                @endif
                                                @if($measurement->label == 'Wt. (lbs.)')
                                                <div>
                                                    <b>{{ round(floatval($measurement->numeric_value), 2) }}</b> lbs
                                                </div>
                                                @endif
                                            </div>
                                        </div>
                                    </div>
                                    <div class="mb-2">
                                        <div class="row">
                                            <div class="col-6 d-flex align-items-center">
                                                <label class="text-secondary text-sm my-0 mr-3 text-nowrap">Time (mins)</label>
                                                <input type="number" min="0" max="5400" class="form-control form-control-sm w-100 cm-time-value" name="timeInMinutes" value="" placeholder="Time (mins.)" required>
                                            </div>
                                        </div>
                                    </div>
                                    <div class="mb-2">
                                        <div class="row">
                                            <div class="col-12 text-left">
                                                <label class="text-secondary text-sm mb-1">Details</label>
                                                <textarea class="form-control form-control-sm" rows="4" name="contentText">{{ 'Reviewed ' . $measurement->label . ' measurement' }}</textarea>
                                            </div>
                                        </div>
                                    </div>
                                    <div class="d-flex align-items-center">
                                        <button class="btn btn-sm btn-success mr-2" submit>Submit</button>
                                        <button class="btn btn-sm btn-default mr-2 border" cancel>Cancel</button>
                                    </div>
                                </form>
                            </span>
                        </div>
                    </td>
                </tr>
            <?php endforeach ?>
        @else
            <tr>
                <td class="text-secondary p-0 p-3" colspan="7">
                    No items to show
                </td>
            </tr>
        @endif
    </tbody>
</table>
<ul class="dashboard-measurements pagination mt-3">

    <?php $totalPages = ceil($numMeasurements / $page); ?>

    <li class="page-item {{ $page === 1 ? 'disabled' : ''}}" aria-disabled="true" aria-label="« Previous">
        @if($page == 1)
            <span class="page-link" aria-hidden="true">‹</span>
        @else
            <a native target="_top" class="page-link" href="#" data-target-page="{{$page - 1}}">‹</a>
        @endif
    </li>

    <li class="page-item"><span class="page-link text-secondary">Showing {{(($page-1) * 20) + 1}} to {{$numMeasurements < $page * 20 ? $numMeasurements : $page * 20}} of {{$numMeasurements}} measurements</span></li>

    <li class="page-item {{ $page === $totalPages ? 'disabled' : ''}}">
        @if($page === $totalPages)
            <span class="page-link" aria-hidden="true">›</span>
        @else
            <a native target="_top" class="page-link" href="#" data-target-page="{{$page + 1}}">›</a>
        @endif
    </li>
</ul>
